@@ -458,29 +458,41 @@ def cache_BDRF_Fourier_modes(N, mu0, BDRF_Fourier_modes):
     mu0 : float
         Cosine of polar angle of the incident beam.
     BDRF_Fourier_modes : list of functions
-        BDRF Fourier modes, each a function with arguments ``mu, -mu_p`` of type array
-        and which output has the same dimensions as the outer product of the two arrays.
+        BDRF Fourier modes, each a scalar, or a function with arguments ``mu, -mu_p`` of type array
+        which output has the same dimensions as the outer product of the two arrays.
 
     Returns
     -------
     cached_BDRF_Fourier_modes : list of functions
         Cached BDRF Fourier modes, each a function with arguments ``mu, -mu_p`` of type array
-        and which output has the same dimensions as the outer product of the two arrays.
+        and which output is a scalar (if the Fourier mode was a scalar) 
+        or has the same dimensions as the outer product of the two arrays.
     """
     NBDRF = len(BDRF_Fourier_modes)
     mu_arr_pos = Gauss_Legendre_quad(N)[0]
 
-    BDRF_Fourier_modes_evaluated = [
-        BDRF_Fourier_modes[m](mu_arr_pos, np.append(mu_arr_pos, mu0)) for m in range(NBDRF)
-    ]
-    cached_BDRF_Fourier_modes = [
+    [
         (
-            lambda mu, neg_mup, m=m: BDRF_Fourier_modes_evaluated[m][:, [-1]]
-            if len(neg_mup) == 1
-            else BDRF_Fourier_modes_evaluated[m][:, :-1]
+            None
+            if np.isscalar(BDRF_Fourier_modes[m])
+            else BDRF_Fourier_modes[m](mu_arr_pos, np.append(mu_arr_pos, mu0))
         )
         for m in range(NBDRF)
     ]
+
+    cached_BDRF_Fourier_modes = [
+        (
+            lambda mu, neg_mup, m=m: BDRF_Fourier_modes[m]
+            if np.isscalar(BDRF_Fourier_modes[m])
+            else (
+                BDRF_Fourier_modes_evaluated[m][:, [-1]]
+                if len(neg_mup) == 1
+                else BDRF_Fourier_modes_evaluated[m][:, :-1]
+            )
+        )
+        for m in range(NBDRF)
+    ]
+
     return cached_BDRF_Fourier_modes
 
 
